RepoAllServicers class

Inheritance
Implemented types

Constructors

RepoAllServicers(EndpointAllServicers endpoint)

Properties

endpoint EndpointAllServicers
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllServicers() Future<ResponseAllServicers>
override
handle<T>(Future<T> response) Future<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited